import { Autocomplete, CircularProgress, TextField } from '@mui/material'
import React, { Fragment, useEffect, useState } from 'react'

interface DataGridCellAutocompleteProps {
    selectedOption: any;
    setSelectedOption: any;
    isLoading: boolean;
    setDebouncedSearch: any;
    options: any;
    setOptions: any;
}

export default function DataGridCellAutocomplete({
    selectedOption,
    setSelectedOption,
    isLoading,
    setDebouncedSearch,
    options,
    setOptions
}: DataGridCellAutocompleteProps) {
    const [open, setOpen] = useState(false)
    const [search, setSearch] = useState<string | null>("")

    useEffect(() => {
        const handler = setTimeout(() => {
            setDebouncedSearch(search)
        }, 500)

        return () => {
            clearTimeout(handler)
        }
    }, [search])

    const handleInputChange = (value: string) => {
        setSearch(value)
    }

    const handleOptionChange = (value: any | null) => {
        setSelectedOption(value)
    }

    return (
        <Autocomplete
            sx={{ flexGrow: '1' }}
            open={open}
            onOpen={() => {
                setOpen(true)
            }}
            onClose={() => {
                setOpen(false)
            }}
            onInputChange={(_, value) => handleInputChange(value)}
            onChange={(_, value) => handleOptionChange(value)}
            filterOptions={(x) => x}
            isOptionEqualToValue={(option: any, value: any) => option.name === value.name}
            getOptionLabel={(option: any) => option.name ? option.name : ""}
            options={options}
            loading={isLoading}
            value={selectedOption}
            renderInput={(params) => (
                <TextField
                    {...params}
                    size='small'
                    label="Район"
                    variant='standard'
                    InputProps={{
                        ...params.InputProps,
                        endAdornment: (
                            <Fragment>
                                {isLoading ? <CircularProgress color="inherit" size={20} /> : null}
                                {params.InputProps.endAdornment}
                            </Fragment>
                        )
                    }}
                />
            )}
        />
    )
}